fn report(
key: &PublicKey,
identity: &NodeIdentityPayload,
packet: &ReceivedPacketRef<'_>,
asked: Option<u32>,
started: Instant,
)Expand description
Print one node, the first time it is heard.
fn report(
key: &PublicKey,
identity: &NodeIdentityPayload,
packet: &ReceivedPacketRef<'_>,
asked: Option<u32>,
started: Instant,
)Print one node, the first time it is heard.