fn steer_through(
routes: &RouteCache,
peer: &PublicKey,
) -> Result<Vec<RouterHint>>Expand description
The router hints that steer a question through peer to whatever is
around it.
fn steer_through(
routes: &RouteCache,
peer: &PublicKey,
) -> Result<Vec<RouterHint>>The router hints that steer a question through peer to whatever is
around it.