precision_cell

Function precision_cell 

fn precision_cell(bytes: u8) -> &'static str
The approximate cell size one precision names, at the equator. What makes a precision meaningful is how large an area it discloses.