pub async fn lora_parts<L: FrameLink>(device: &mut UlcpDevice<L>) -> Vec<String>Expand description
The LoRa modulation parameters, each omitted when the device will not report it.
pub async fn lora_parts<L: FrameLink>(device: &mut UlcpDevice<L>) -> Vec<String>The LoRa modulation parameters, each omitted when the device will not report it.