fn same_name(name: &str, written: &str) -> bool
Whether written names the property name spells, ignoring case and the difference between a dash and an underscore, with the PROP_ prefix optional.
written
name
PROP_