fn region_codes(regions: &[String]) -> Vec<RegionCode>Expand description
The codes a stored region list derives to, for the cross-checks that compare against a default region.
fn region_codes(regions: &[String]) -> Vec<RegionCode>The codes a stored region list derives to, for the cross-checks that compare against a default region.