TimeOp

Enum TimeOp 

pub enum TimeOp {
    Show,
    Sync,
    Set {
        epoch: u32,
    },
    Clear,
    Tz {
        op: Option<TzOp>,
    },
}

Variants



Show

Print the device’s clock, in UTC and in its configured local time.



Sync

Set the clock from this host’s clock.



Set

Set the clock to an explicit Unix second count.

Fields

epoch: u32


Clear

Return the device to not knowing what time it is. A device with a screen stops showing a clock at all.



Tz

Show or set the local time-zone offset.

Fields