parse_endpoint

Function parse_endpoint 

pub fn parse_endpoint(spec: &str) -> Result<(String, u16)>
Parse a host:port endpoint, accepting a bracketed IPv6 literal.

The port is required: a bare host would have to guess a port number, and there is no registered one to guess.